# cicdstatemgr

[![PyPI version](https://badge.fury.io/py/cicdstatemgr.svg)](https://badge.fury.io/py/cicdstatemgr)

`cicdstatemgr` is a Python package who's intent is to make your life a bit easier when developing a CICD solution that needs to maintain state across multiple workflows and contexts of execution while providing a framework for enabling end-user interaction via tools like Slack.

This project was born out of needs that arised when building a custom CI/CD solution using the Kubernetes native [Tekton Pipelines](https://github.com/tektoncd/pipeline) project.

* [Examples](examples/) 
* [Install](#install)


## Install

